@@ -6,7 +6,7 @@ pub mod price;
 use super::payee;
 
 pub type Id = String;
-pub type Plans = std::collections::BTreeMap<Id, PaymentPlan>;
+pub type Plans = std::collections::BTreeMap<Id, Plan>;
 pub type SplitPercent = String;
 
 pub fn next_id(plans: &Plans) -> Result<Id> {
@@ -44,28 +44,30 @@ impl std::str::FromStr for PlanType {
     }
 }
 
-// TODO: Rename to 'Plan'.
 #[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
-pub struct PaymentPlan {
+pub struct Plan {
     pub r#type: PlanType,
     pub conditions: conditions::Conditions,
     pub payments: Payments,
 }
 
-impl PaymentPlan {
-    pub fn is_applicable(&self, config: &crate::config::Config) -> Result<bool> {
+impl Plan {
+    pub fn is_applicable(
+        &self,
+        parameters: &crate::lock::plan::conditions::Parameters,
+    ) -> Result<bool> {
         Ok(match self.r#type {
             PlanType::Voluntary => {
                 // Voluntary plans are subject to conditions.
-                config.include_voluntary_plans && self.conditions.evaluate(&config)?
+                parameters.include_voluntary_plans && self.conditions.evaluate(&parameters)?
             }
             PlanType::Compulsory => {
                 // Non-commercial not subject to compulsory plans.
-                if !config.commercial {
+                if !parameters.commercial {
                     false
                 } else {
                     // Commercial are subject to compulsory plans based on conditions.
-                    self.conditions.evaluate(&config)?
+                    self.conditions.evaluate(&parameters)?
                 }
             }
         })
@@ -73,10 +75,13 @@ impl PaymentPlan {
 }
 
 /// Filter for applicable plans.
-pub fn filter_applicable(plans: &Plans, config: &crate::config::Config) -> Result<Plans> {
+pub fn filter_applicable(
+    plans: &Plans,
+    parameters: &crate::lock::plan::conditions::Parameters,
+) -> Result<Plans> {
     let mut applicable_plans = Plans::new();
     for (plan_id, plan) in plans {
-        if plan.is_applicable(&config)? {
+        if plan.is_applicable(&parameters)? {
             applicable_plans.insert(plan_id.clone(), plan.clone());
         }
     }
